class Admin::ArchiveExamFilesController < OrbitAdminController

  def index
    @table_fields = [:status, :category, :title, :update_at,:last_modified]
    @categories = @module_app.categories
    @tags = @module_app.tags
    @filter_fields = filter_fields(@categories, @tags)

    @archive_exams = ArchiveExamFile.order_by(sort)
                                              .with_categories(filters("category"))
                                              .with_tags(filters("tag"))
                                              .with_status(filters("status"))

    @archive_exams = search_data(@archive_exams,[:title]).page(params[:page]).per(10)

    render :partial => "index" if request.xhr?
  end

  def new
     @archive_exam_file = ArchiveExamFile.new
     @tags = @module_app.tags
     @categories = @module_app.categories

    @archive_exam_test_types = ArchiveExamTestType.all
    @archive_exam_grades = ArchiveExamGrade.all
    @archive_exam_colleges = ArchiveExamCollege.all
    @archive_exam_departments = ArchiveExamDepartment.all
    @archive_exam_subjects = ArchiveExamSubject.all

  end

  def edit

    @archive_exam_test_types = ArchiveExamTestType.all
    @archive_exam_grades = ArchiveExamGrade.all
    @archive_exam_colleges = ArchiveExamCollege.all
    @archive_exam_departments = ArchiveExamDepartment.all
    @archive_exam_subjects = ArchiveExamSubject.all

    @archive_exam_file = ArchiveExamFile.find(params[:id])
    if can_edit_or_delete?(@archive_exam_file)
     @tags = @module_app.tags
     @categories = @module_app.categories
    else
      render_401
    end
  end

  def create
    @archive_exam_file = ArchiveExamFile.new(archive_exam_vars)

    @archive_exam_file.create_user_id = current_user.id
    @archive_exam_file.update_user_id = current_user.id

    respond_to do |format|
      if @archive_exam_file.save
        format.html { redirect_to(admin_archive_exam_files_path) }
        format.xml  { render :xml => @archive_exam_file, :status => :created, :location => @archive_exam_file }
      else
        @tags = @module_app.tags
        format.html { render :action => "new" }
        format.xml  { render :xml => @archive_exam_file.errors, :status => :unprocessable_entity }
      end
    end
  end

  # PUT /archive_exam_files/1
  # PUT /archive_exam_files/1.xml
  def update
    params[:archive_exam_file][:archive_exam_test_type_id] = (params[:archive_exam_file][:archive_exam_test_type_id] ? params[:archive_exam_file][:archive_exam_test_type_id] : [])
    params[:archive_exam_file][:archive_exam_grade_id] = (params[:archive_exam_file][:archive_exam_grade_id] ? params[:archive_exam_file][:archive_exam_grade_id] : [])
    params[:archive_exam_file][:archive_exam_college_id] = (params[:archive_exam_file][:archive_exam_college_id] ? params[:archive_exam_file][:archive_exam_college_id] : [])
    params[:archive_exam_file][:archive_exam_department_id] = (params[:archive_exam_file][:archive_exam_department_id] ? params[:archive_exam_file][:archive_exam_department_id] : [])
    params[:archive_exam_file][:archive_exam_subject_id] = (params[:archive_exam_file][:archive_exam_subject_id] ? params[:archive_exam_file][:archive_exam_subject_id] : [])

    

    @archive_exam_file = ArchiveExamFile.find(params[:id])
    @archive_exam_file.update_user_id = current_user.id

    respond_to do |format|
      if @archive_exam_file.update_attributes(archive_exam_vars)
        format.html { redirect_to(admin_archive_exam_files_path(:page => params[:page])) }
        format.xml  { head :ok }
      else
        format.html { render :action => "edit" }
        format.xml  { render :xml => @archive_exam_file.errors, :status => :unprocessable_entity }
      end
    end
  end

  def destroy
    archive_exam_file = ArchiveExamFile.find(params[:id])
    archive_exam_file.destroy
    redirect_to admin_archive_exam_files_path
  end

  private

  def archive_exam_vars
    params[:archive_exam_file][:tags] ||=[]
    params.require(:archive_exam_file).permit!
  end

  def setup_vars
    @module_app = ModuleApp.where(:key => "archive_exam").first
  end
  def sort
    unless params[:sort].blank?
      case params[:sort]
        when "status"
          @sort = [[:is_top, params[:order]],
                  [:is_hot, params[:order]],
                  [:is_hidden,params[:order]]]
        when "category"
          @sort = {:category_id=>params[:order]}
        when "title"
          @sort = {:title=>params[:order]}
        when "last_modified"
          @sort = {:update_user_id=>params[:order]}
      end
    else
      @sort = {:created_at=>'desc'}
    end
  @sort
  end
end
